package com.xinelu.manage.service.specialdiseaseroutepackage.impl;

import com.xinelu.manage.domain.specialdiseaseroutepackage.SpecialDiseaseRoutePackage;
import com.xinelu.manage.mapper.specialdiseaseroutepackage.SpecialDiseaseRoutePackageMapper;
import com.xinelu.manage.service.specialdiseaseroutepackage.ISpecialDiseaseRoutePackageService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.util.List;

/**
 * 专病路径-服务包关系（多对多关系）Service业务层处理
 *
 * @author xinelu
 * @date 2024-04-09
 */
@Service
public class SpecialDiseaseRoutePackageServiceImpl implements ISpecialDiseaseRoutePackageService {
    @Resource
    private SpecialDiseaseRoutePackageMapper specialDiseaseRoutePackageMapper;

    /**
     * 查询专病路径-服务包关系（多对多关系）
     *
     * @param id 专病路径-服务包关系（多对多关系）主键
     * @return 专病路径-服务包关系（多对多关系）
     */
    @Override
    public SpecialDiseaseRoutePackage selectSpecialDiseaseRoutePackageById(Long id) {
        return specialDiseaseRoutePackageMapper.selectSpecialDiseaseRoutePackageById(id);
    }

    /**
     * 查询专病路径-服务包关系（多对多关系）列表
     *
     * @param specialDiseaseRoutePackage 专病路径-服务包关系（多对多关系）
     * @return 专病路径-服务包关系（多对多关系）
     */
    @Override
    public List<SpecialDiseaseRoutePackage> selectSpecialDiseaseRoutePackageList(SpecialDiseaseRoutePackage specialDiseaseRoutePackage) {
        return specialDiseaseRoutePackageMapper.selectSpecialDiseaseRoutePackageList(specialDiseaseRoutePackage);
    }

    /**
     * 新增专病路径-服务包关系（多对多关系）
     *
     * @param specialDiseaseRoutePackage 专病路径-服务包关系（多对多关系）
     * @return 结果
     */
    @Override
    public int insertSpecialDiseaseRoutePackage(SpecialDiseaseRoutePackage specialDiseaseRoutePackage) {
        specialDiseaseRoutePackage.setCreateTime(LocalDateTime.now());
        return specialDiseaseRoutePackageMapper.insertSpecialDiseaseRoutePackage(specialDiseaseRoutePackage);
    }

    /**
     * 修改专病路径-服务包关系（多对多关系）
     *
     * @param specialDiseaseRoutePackage 专病路径-服务包关系（多对多关系）
     * @return 结果
     */
    @Override
    public int updateSpecialDiseaseRoutePackage(SpecialDiseaseRoutePackage specialDiseaseRoutePackage) {
        specialDiseaseRoutePackage.setUpdateTime(LocalDateTime.now());
        return specialDiseaseRoutePackageMapper.updateSpecialDiseaseRoutePackage(specialDiseaseRoutePackage);
    }

    /**
     * 批量删除专病路径-服务包关系（多对多关系）
     *
     * @param ids 需要删除的专病路径-服务包关系（多对多关系）主键
     * @return 结果
     */
    @Override
    public int deleteSpecialDiseaseRoutePackageByIds(Long[] ids) {
        return specialDiseaseRoutePackageMapper.deleteSpecialDiseaseRoutePackageByIds(ids);
    }

    /**
     * 删除专病路径-服务包关系（多对多关系）信息
     *
     * @param id 专病路径-服务包关系（多对多关系）主键
     * @return 结果
     */
    @Override
    public int deleteSpecialDiseaseRoutePackageById(Long id) {
        return specialDiseaseRoutePackageMapper.deleteSpecialDiseaseRoutePackageById(id);
    }
}
